==> kmem-ps-0.99.14.tar.gz: kmem-ps-0.99.14/syscallent.h <==
	{ 0, 0, "indir"},		/* 0 */
	{ 1, 01, "exit"},		/* 1 */
	{ 0, 0, "fork"},		/* 2 */
	{ 3, 05, "read"},		/* 3 */
	{ 3, 05, "write"},		/* 4 */
	{ 3, 0, "open"},		/* 5 */
	{ 1, 01, "close"},		/* 6 */
	{ 3, 01, "waitpid"},		/* 7 */
	{ 2, 0, "creat"},		/* 8 */
	{ 2, 0, "link"},		/* 9 */
	{ 1, 0, "unlink"},		/* 10 */
	{ 3, 0, "execve"},		/* 11 */
	{ 1, 0, "chdir"},		/* 12 */
	{ 1, 0, "time"},		/* 13 */
	{ 3, 0, "mknod"},		/* 14 */
	{ 2, 0, "chmod"},		/* 15 */
	{ 3, 06, "chown"},		/* 16 */
	{ 0, 0, "break"},		/* 17 */
	{ 2, 0, "oldstat"},		/* 18 */
	{ 3, 07, "lseek"},		/* 19 */
	{ 0, 0, "getpid"},		/* 20 */
	{ 5, 0, "mount"},		/* 21 */
	{ 1, 0, "umount"},		/* 22 */
	{ 1, 01, "setuid"},		/* 23 */
	{ 0, 0, "getuid"},		/* 24 */
	{ 1, 0, "stime"},		/* 25 */
	{ 4, 0, "ptrace"},		/* 26 */
	{ 1, 01, "alarm"},		/* 27 */
	{ 2, 01, "oldfstat"},		/* 28 */
	{ 0, 0, "pause"},		/* 29 */
	{ 2, 0, "utime"},		/* 30 */
	{ 2, 0, "stty"},		/* 31 */
	{ 2, 0, "gtty"},		/* 32 */
	{ 2, 0, "access"},		/* 33 */
	{ 1, 01, "nice"},		/* 34 */
	{ 0, 0, "ftime"},		/* 35 */
	{ 0, 0, "sync"},		/* 36 */
	{ 2, 03, "kill"},		/* 37 */
	{ 2, 0, "rename"},		/* 38 */
	{ 2, 0, "mkdir"},		/* 39 */
	{ 1, 0, "rmdir"},		/* 40 */
	{ 1, 01, "dup"},		/* 41 */
	{ 1, 0, "pipe"},		/* 42 */
	{ 1, 0, "times"},		/* 43 */
	{ 0, 0, "prof"},		/* 44 */
	{ 1, 0, "brk"},			/* 45 */
	{ 1, 01, "setgid"},		/* 46 */
	{ 0, 0, "getgid"},		/* 47 */
	{ 3, 01, "signal"},		/* 48 */
	{ 0, 0, "geteuid"},		/* 49 */
	{ 0, 0, "getegid"},		/* 50 */
	{ 1, 0, "acct"},		/* 51 */
	{ 0, 0, "phys"},		/* 52 */
	{ 0, 0, "lock"},		/* 53 */
	{ 3, 01, "ioctl"},		/* 54 */
	{ 3, 01, "fcntl"},		/* 55 */
	{ 0, 0, "mpx"},			/* 56 */
	{ 2, 03, "setpgid"},		/* 57 */
	{ 2, 0, "ulimit"},		/* 58 */
	{ 1, 0, "oldolduname"},		/* 59 */
	{ 1, 0, "umask"},		/* 60 */
	{ 1, 0, "chroot"},		/* 61 */
	{ 2, 0, "ustat"},		/* 62 */
	{ 2, 03, "dup2"},		/* 63 */
	{ 0, 0, "getppid"},		/* 64 */
	{ 0, 0, "getpgrp"},		/* 65 */
	{ 0, 0, "setsid"},		/* 66 */
	{ 3, 01, "sigaction"},		/* 67 */
	{ 0, 0, "sgetmask"},		/* 68 */
	{ 1, 0, "ssetmask"},		/* 69 */
	{ 2, 03, "setreuid"},		/* 70 */
	{ 2, 03, "setregid"},		/* 71 */
	{ 3, 01, "sigsuspend"},		/* 72 */
	{ 1, 0, "sigpending"},		/* 73 */
	{ 2, 0, "sethostname"},		/* 74 */
	{ 2, 01, "setrlimit"},		/* 75 */
	{ 2, 01, "getrlimit"},		/* 76 */
	{ 2, 01, "getrusage"},		/* 77 */
	{ 2, 0, "gettimeofday"},	/* 78 */
	{ 2, 0, "settimeofday"},	/* 79 */
	{ 2, 0, "getgroups"},		/* 80 */
	{ 2, 0, "setgroups"},		/* 81 */
	{ 1, 0, "select"},		/* 82 */
	{ 2, 0, "symlink"},		/* 83 */
	{ 2, 0, "oldlstat"},		/* 84 */
	{ 3, 0, "readlink"},		/* 85 */
	{ 1, 0, "uselib"},		/* 86 */
	{ 1, 0, "swapon"},		/* 87 */
	{ 3, 0, "reboot"},		/* 88 */
	{ 3, 05, "readdir"},		/* 89 */
	{ 1, 0, "mmap"},		/* 90 */
	{ 2, 0, "munmap"},		/* 91 */
	{ 2, 02, "truncate"},		/* 92 */
	{ 2, 03, "ftruncate"},		/* 93 */
	{ 2, 01, "fchmod"},		/* 94 */
	{ 3, 07, "fchown"},		/* 95 */
	{ 2, 03, "getpriority"},	/* 96 */
	{ 3, 07, "setpriority"},	/* 97 */
	{ 4, 0, "profil"},		/* 98 */
	{ 2, 0, "statfs"},		/* 99 */
	{ 2, 01, "fstatfs"},		/* 100 */
	{ 3, 0, "ioperm"},		/* 101 */
	{ 2, 01, "socketcall"},		/* 102 */
	{ 3, 05, "syslog"},		/* 103 */
	{ 3, 01, "setitimer"},		/* 104 */
	{ 2, 01, "getitimer"},		/* 105 */
	{ 2, 0, "stat"},		/* 106 */
	{ 2, 0, "lstat"},		/* 107 */
	{ 2, 01, "fstat"},		/* 108 */
	{ 1, 0, "olduname"},		/* 109 */
	{ 1, 0, "iopl"},		/* 110 */
	{ 0, 0, "vhangup"},		/* 111 */
	{ 0, 0, "idle"},		/* 112 */
	{ 1, 0, "vm86"},		/* 113 */
	{ 4, 01, "wait4"},		/* 114 */
	{ 1, 0, "swapoff"},		/* 115 */
	{ 1, 0, "sysinfo"},		/* 116 */
	{ 5, 0, "ipc"},			/* 117 */
	{ 1, 01, "fsync"},		/* 118 */
	{ 1, 0, "sigreturn"},		/* 119 */
	{ 1, 0, "clone"},		/* 120 */
	{ 2, 0, "setdomainname"},	/* 121 */
	{ 1, 0, "uname"},		/* 122 */
	{ 3, 05, "modify_ldt"},		/* 123 */
	{ 1, 0, "adjtimex"},		/* 124 */
	{ 3, 02, "mprotect"},		/* 125 */
	{ 3, 01, "sigprocmask"},	/* 126 */

==> kmem-ps-1.1.11.tar.gz: kmem-ps-1.1.11/syscallent.h <==
	{ 0, 0, "indir"},		/* 0 */
	{ 1, 01, "exit"},		/* 1 */
	{ 0, 0, "fork"},		/* 2 */
	{ 3, 05, "read"},		/* 3 */
	{ 3, 05, "write"},		/* 4 */
	{ 3, 0, "open"},		/* 5 */
	{ 1, 01, "close"},		/* 6 */
	{ 3, 01, "waitpid"},		/* 7 */
	{ 2, 0, "creat"},		/* 8 */
	{ 2, 0, "link"},		/* 9 */
	{ 1, 0, "unlink"},		/* 10 */
	{ 3, 0, "execve"},		/* 11 */
	{ 1, 0, "chdir"},		/* 12 */
	{ 1, 0, "time"},		/* 13 */
	{ 3, 0, "mknod"},		/* 14 */
	{ 2, 0, "chmod"},		/* 15 */
	{ 3, 06, "chown"},		/* 16 */
	{ 0, 0, "break"},		/* 17 */
	{ 2, 0, "oldstat"},		/* 18 */
	{ 3, 07, "lseek"},		/* 19 */
	{ 0, 0, "getpid"},		/* 20 */
	{ 5, 0, "mount"},		/* 21 */
	{ 1, 0, "umount"},		/* 22 */
	{ 1, 01, "setuid"},		/* 23 */
	{ 0, 0, "getuid"},		/* 24 */
	{ 1, 0, "stime"},		/* 25 */
	{ 4, 0, "ptrace"},		/* 26 */
	{ 1, 01, "alarm"},		/* 27 */
	{ 2, 01, "oldfstat"},		/* 28 */
	{ 0, 0, "pause"},		/* 29 */
	{ 2, 0, "utime"},		/* 30 */
	{ 2, 0, "stty"},		/* 31 */
	{ 2, 0, "gtty"},		/* 32 */
	{ 2, 0, "access"},		/* 33 */
	{ 1, 01, "nice"},		/* 34 */
	{ 0, 0, "ftime"},		/* 35 */
	{ 0, 0, "sync"},		/* 36 */
	{ 2, 03, "kill"},		/* 37 */
	{ 2, 0, "rename"},		/* 38 */
	{ 2, 0, "mkdir"},		/* 39 */
	{ 1, 0, "rmdir"},		/* 40 */
	{ 1, 01, "dup"},		/* 41 */
	{ 1, 0, "pipe"},		/* 42 */
	{ 1, 0, "times"},		/* 43 */
	{ 0, 0, "prof"},		/* 44 */
	{ 1, 0, "brk"},			/* 45 */
	{ 1, 01, "setgid"},		/* 46 */
	{ 0, 0, "getgid"},		/* 47 */
	{ 3, 01, "signal"},		/* 48 */
	{ 0, 0, "geteuid"},		/* 49 */
	{ 0, 0, "getegid"},		/* 50 */
	{ 1, 0, "acct"},		/* 51 */
	{ 0, 0, "phys"},		/* 52 */
	{ 0, 0, "lock"},		/* 53 */
	{ 3, 01, "ioctl"},		/* 54 */
	{ 3, 01, "fcntl"},		/* 55 */
	{ 0, 0, "mpx"},			/* 56 */
	{ 2, 03, "setpgid"},		/* 57 */
	{ 2, 0, "ulimit"},		/* 58 */
	{ 1, 0, "oldolduname"},		/* 59 */
	{ 1, 0, "umask"},		/* 60 */
	{ 1, 0, "chroot"},		/* 61 */
	{ 2, 0, "ustat"},		/* 62 */
	{ 2, 03, "dup2"},		/* 63 */
	{ 0, 0, "getppid"},		/* 64 */
	{ 0, 0, "getpgrp"},		/* 65 */
	{ 0, 0, "setsid"},		/* 66 */
	{ 3, 01, "sigaction"},		/* 67 */
	{ 0, 0, "sgetmask"},		/* 68 */
	{ 1, 0, "ssetmask"},		/* 69 */
	{ 2, 03, "setreuid"},		/* 70 */
	{ 2, 03, "setregid"},		/* 71 */
	{ 3, 01, "sigsuspend"},		/* 72 */
	{ 1, 0, "sigpending"},		/* 73 */
	{ 2, 0, "sethostname"},		/* 74 */
	{ 2, 01, "setrlimit"},		/* 75 */
	{ 2, 01, "getrlimit"},		/* 76 */
	{ 2, 01, "getrusage"},		/* 77 */
	{ 2, 0, "gettimeofday"},	/* 78 */
	{ 2, 0, "settimeofday"},	/* 79 */
	{ 2, 0, "getgroups"},		/* 80 */
	{ 2, 0, "setgroups"},		/* 81 */
	{ 1, 0, "select"},		/* 82 */
	{ 2, 0, "symlink"},		/* 83 */
	{ 2, 0, "oldlstat"},		/* 84 */
	{ 3, 0, "readlink"},		/* 85 */
	{ 1, 0, "uselib"},		/* 86 */
	{ 1, 0, "swapon"},		/* 87 */
	{ 3, 0, "reboot"},		/* 88 */
	{ 3, 05, "readdir"},		/* 89 */
	{ 1, 0, "mmap"},		/* 90 */
	{ 2, 0, "munmap"},		/* 91 */
	{ 2, 02, "truncate"},		/* 92 */
	{ 2, 03, "ftruncate"},		/* 93 */
	{ 2, 01, "fchmod"},		/* 94 */
	{ 3, 07, "fchown"},		/* 95 */
	{ 2, 03, "getpriority"},	/* 96 */
	{ 3, 07, "setpriority"},	/* 97 */
	{ 4, 0, "profil"},		/* 98 */
	{ 2, 0, "statfs"},		/* 99 */
	{ 2, 01, "fstatfs"},		/* 100 */
	{ 3, 0, "ioperm"},		/* 101 */
	{ 2, 01, "socketcall"},		/* 102 */
	{ 3, 05, "syslog"},		/* 103 */
	{ 3, 01, "setitimer"},		/* 104 */
	{ 2, 01, "getitimer"},		/* 105 */
	{ 2, 0, "stat"},		/* 106 */
	{ 2, 0, "lstat"},		/* 107 */
	{ 2, 01, "fstat"},		/* 108 */
	{ 1, 0, "olduname"},		/* 109 */
	{ 1, 0, "iopl"},		/* 110 */
	{ 0, 0, "vhangup"},		/* 111 */
	{ 0, 0, "idle"},		/* 112 */
	{ 1, 0, "vm86"},		/* 113 */
	{ 4, 01, "wait4"},		/* 114 */
	{ 1, 0, "swapoff"},		/* 115 */
	{ 1, 0, "sysinfo"},		/* 116 */
	{ 5, 0, "ipc"},			/* 117 */
	{ 1, 01, "fsync"},		/* 118 */
	{ 1, 0, "sigreturn"},		/* 119 */
	{ 1, 0, "clone"},		/* 120 */
	{ 2, 0, "setdomainname"},	/* 121 */
	{ 1, 0, "uname"},		/* 122 */
	{ 3, 05, "modify_ldt"},		/* 123 */
	{ 1, 0, "adjtimex"},		/* 124 */
	{ 3, 02, "mprotect"},		/* 125 */
	{ 3, 01, "sigprocmask"},	/* 126 */
	/****/
	{ 2, 02, "create_module"},	/* 127 */
	{ 4, 0, "init_modlule"},	/* 128 */
	{ 1, 0, "delete_module"},	/* 129 */
	{ 1, 0, "get_kernel_syms"},	/* 130 */
	{ 3, 0, "quota_ctl"},		/* 131 */
	{ 0, 0, "getpgid"},		/* 132 */
	{ 1, 01, "fchdir"},		/* 133 */
	{ 2, 03, "bdflush"},		/* 134 */
	{ 3, 0, "sysfs"},		/* 135 */
